/*
 *  * Copyright (C) 2024, KylinSoft Co., Ltd.
 *  *
 *  * This program is free software: you can redistribute it and/or modify
 *  * it under the terms of the GNU General Public License as published by
 *  * the Free Software Foundation, either version 3 of the License, or
 *  * (at your option) any later version.
 *  *
 *  * This program is distributed in the hope that it will be useful,
 *  * but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  * GNU General Public License for more details.
 *  *
 *  * You should have received a copy of the GNU General Public License
 *  * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *  *
 *  * Authors: iaom <zhangpengfei@kylinos.cn>
 *
 */

#ifndef UKUI_PANEL_SCREENS_MANAGER_H
#define UKUI_PANEL_SCREENS_MANAGER_H
#include <QObject>
#include <QScreen>
class ScreensManager;
class PanelScreen : public QObject
{
    Q_OBJECT
public:
    explicit PanelScreen(QScreen *screen, QObject *parent = nullptr);
    Q_DISABLE_COPY(PanelScreen);

public:
    QRect geometry() const;
    QScreen * internal();
    bool enable();

Q_SIGNALS:
    void geometryChanged(const QRect &geometry);
    void enableChanged(bool enable);

public Q_SLOTS:
    void checkGeometry();
private Q_SLOTS:
    void onGeometryChanged(const QRect &geometry);

private:
    QScreen *m_screen = nullptr;
    bool m_enable = false;
};
class ScreensManager : public QObject
{
    Q_OBJECT
public:
    explicit ScreensManager(QObject *parent = nullptr);
    ~ScreensManager();
    QList<PanelScreen *> screens();
    PanelScreen * primaryScreen();

Q_SIGNALS:
    void screenAdded(PanelScreen *);
    void screenRemoved(PanelScreen *);
    void primaryScreenChanged(PanelScreen *);

private Q_SLOTS:
    void onScreenAdded(QScreen *screen);
    void onScreenRemoved(QScreen *screen);
    void onPrimaryScreenChanged(QScreen *screen);
    void onEnableChanged(PanelScreen *screen, bool enable);
    void onGeometryChanged(PanelScreen *screen, const QRect &geometry);

private:
    PanelScreen *m_primaryScreen = nullptr;
    QList<PanelScreen *> m_screens;

};

#endif //UKUI_PANEL_SCREENS_MANAGER_H
